package
Version:
v0.1.1
Opens a new window with list of versions in this module.
Published: Oct 30, 2017
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Manager interface {
Insert(contentType string, contentItem map[string]interface{})
Delete(contentType string, contentId string)
Update(contentType string, contentItem map[string]interface{}, patch bool)
}
type Publisher interface {
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.